@@ -62,6 +62,7 @@ from .load_tool import (
     resolve_tool_uri,
 )
 from .loghandler import _logger, defaultStreamHandler
+from .mpi import MpiConfig
 from .mutation import MutationManager
 from .pack import pack
 from .process import (
@@ -99,7 +100,6 @@ from .utils import (
     windows_default_container_id,
 )
 from .workflow import Workflow
-from .mpi import MpiConfig
 
 
 def _terminate_processes() -> None:
@@ -132,7 +132,8 @@ def _signal_handler(signum: int, _: Any) -> None:
 
 
 def generate_example_input(
-    inptype: Optional[CWLOutputType], default: Optional[CWLOutputType],
+    inptype: Optional[CWLOutputType],
+    default: Optional[CWLOutputType],
 ) -> Tuple[Any, str]:
     """Convert a single input schema into an example."""
     example = None
@@ -401,7 +402,8 @@ def init_job_order(
         if "job_order" in cmd_line and cmd_line["job_order"]:
             try:
                 job_order_object = cast(
-                    CWLObjectType, loader.resolve_ref(cmd_line["job_order"])[0],
+                    CWLObjectType,
+                    loader.resolve_ref(cmd_line["job_order"])[0],
                 )
             except Exception:
                 _logger.exception(
@@ -582,7 +584,10 @@ def find_deps(
     return deps
 
 
-def print_pack(loadingContext: LoadingContext, uri: str,) -> str:
+def print_pack(
+    loadingContext: LoadingContext,
+    uri: str,
+) -> str:
     """Return a CWL serialization of the CWL document in JSON."""
     packed = pack(loadingContext, uri)
     if len(cast(Sized, packed["$graph"])) > 1:
@@ -666,7 +671,9 @@ class ProvLogFormatter(logging.Formatter):
 
 
 def setup_provenance(
-    args: argparse.Namespace, argsl: List[str], runtimeContext: RuntimeContext,
+    args: argparse.Namespace,
+    argsl: List[str],
+    runtimeContext: RuntimeContext,
 ) -> Optional[int]:
     if not args.compute_checksum:
         _logger.error("--provenance incompatible with --no-compute-checksum")
@@ -719,7 +726,11 @@ def setup_loadingContext(
     return loadingContext
 
 
-def make_template(tool: Process,) -> None:
+def make_template(
+    tool: Process,
+) -> None:
+    """Make a template CWL input object for the give Process."""
+
     def my_represent_none(
         self: Any, data: Any
     ) -> Any:  # pylint: disable=unused-argument
@@ -737,9 +748,11 @@ def make_template(tool: Process,) -> None:
 
 
 def choose_target(
-    args: argparse.Namespace, tool: Process, loadingContext: LoadingContext,
+    args: argparse.Namespace,
+    tool: Process,
+    loadingContext: LoadingContext,
 ) -> Optional[Process]:
-
+    """Walk the given Workflow and find the process that matches args.target."""
     if loadingContext.loader is None:
         raise Exception("loadingContext.loader cannot be None")
 
@@ -769,7 +782,10 @@ def choose_target(
     return tool
 
 
-def check_working_directories(runtimeContext: RuntimeContext,) -> Optional[int]:
+def check_working_directories(
+    runtimeContext: RuntimeContext,
+) -> Optional[int]:
+    """Make any needed working directories."""
     for dirprefix in ("tmpdir_prefix", "tmp_outdir_prefix", "cachedir"):
         if (
             getattr(runtimeContext, dirprefix)
